@@ -1,7 +1,6 @@
-/* This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- */
+#![allow(clippy::cast_possible_truncation)]
+#![allow(clippy::cast_possible_wrap)]
+#![allow(clippy::cast_sign_loss)]
 
 use super::*;
 use pretty_assertions::assert_eq;
@@ -663,6 +662,7 @@ mod iter {
         assert_eq!(iter_utils::trie_max_height(64), 11);
     }
 
+    #[allow(clippy::never_loop)]
     #[test]
     fn test_iter_empty() {
         let map: HashTrieMap<i32, i32> = HashTrieMap::new();
@@ -1238,10 +1238,9 @@ fn test_clone() {
 #[cfg(feature = "serde")]
 #[test]
 fn test_serde() {
-    use bincode::{deserialize, serialize};
     let map: HashTrieMap<i32, i32> = ht_map![5 => 6, 7 => 8, 9 => 10, 11 => 12];
-    let encoded = serialize(&map).unwrap();
-    let decoded: HashTrieMap<i32, i32> = deserialize(&encoded).unwrap();
+    let encoded = serde_json::to_string(&map).unwrap();
+    let decoded: HashTrieMap<i32, i32> = serde_json::from_str(&encoded).unwrap();
 
     assert_eq!(map, decoded);
 }
