@@ -1,8 +1,3 @@
-/* This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- */
-
 use super::entry::Entry;
 use archery::{ArcTK, RcK, SharedPointer, SharedPointerKind};
 use core::borrow::Borrow;
@@ -159,8 +154,8 @@ where
         Node { entry: SharedPointer::new(entry), color: Color::Black, left: None, right: None }
     }
 
-    fn borrow(node: &Option<SharedPointer<Node<K, V, P>, P>>) -> Option<&Node<K, V, P>> {
-        node.as_ref().map(Borrow::borrow)
+    fn borrow(node: Option<&SharedPointer<Node<K, V, P>, P>>) -> Option<&Node<K, V, P>> {
+        node.map(Borrow::borrow)
     }
 
     fn left_color(&self) -> Option<Color> {
@@ -270,9 +265,9 @@ where
     ///                  c   d
     /// ```
     fn balance(&mut self) {
-        use core::mem::swap;
         use Color::Black as B;
         use Color::Red as R;
+        use core::mem::swap;
 
         match self.color {
             B => {
@@ -542,7 +537,7 @@ where
                             }
                         }
                     }
-                };
+                }
 
                 true
             }
@@ -990,7 +985,7 @@ where
     }
 }
 
-impl<'a, K, Q: ?Sized, V, P> Index<&'a Q> for RedBlackTreeMap<K, V, P>
+impl<K, Q: ?Sized, V, P> Index<&Q> for RedBlackTreeMap<K, V, P>
 where
     K: Ord + Borrow<Q>,
     Q: Ord,
@@ -1034,7 +1029,7 @@ where
             return true;
         }
         self.size() == other.size()
-            && self.iter().all(|(key, value)| other.get(key).map_or(false, |v| *value == *v))
+            && self.iter().all(|(key, value)| other.get(key).is_some_and(|v| *value == *v))
     }
 }
 
@@ -1213,7 +1208,7 @@ mod iter_utils {
                 if !in_range {
                     self.stack.clear();
                 }
-            };
+            }
         }
 
         #[inline]
@@ -1227,7 +1222,7 @@ mod iter_utils {
             Q: Ord + ?Sized,
         {
             let child = self.stack.last().and_then(|node| {
-                let c = if self.backwards { &node.right } else { &node.left };
+                let c = if self.backwards { node.right.as_ref() } else { node.left.as_ref() };
                 Node::borrow(c)
             });
 
@@ -1284,7 +1279,7 @@ mod iter_utils {
             Q: Ord + ?Sized,
         {
             if let Some(node) = self.stack.pop() {
-                let child = if self.backwards { &node.left } else { &node.right };
+                let child = if self.backwards { node.left.as_ref() } else { node.right.as_ref() };
 
                 if let Some(c) = Node::borrow(child) {
                     self.stack.push(c);
@@ -1305,11 +1300,7 @@ mod iter_utils {
     }
 
     pub fn conservative_height(size: usize) -> usize {
-        if size > 0 {
-            2 * lg_floor(size + 1)
-        } else {
-            0
-        }
+        if size > 0 { 2 * lg_floor(size + 1) } else { 0 }
     }
 }
 
@@ -1324,7 +1315,7 @@ where
     size: usize,
 }
 
-impl<'a, K, V, P> IterPtr<'a, K, V, P>
+impl<K, V, P> IterPtr<'_, K, V, P>
 where
     K: Ord,
     P: SharedPointerKind,
@@ -1370,7 +1361,7 @@ where
     }
 }
 
-impl<'a, K: Ord, V, P> ExactSizeIterator for IterPtr<'a, K, V, P> where P: SharedPointerKind {}
+impl<K: Ord, V, P> ExactSizeIterator for IterPtr<'_, K, V, P> where P: SharedPointerKind {}
 
 #[derive(Debug)]
 pub struct RangeIterPtr<'a, K, V, RB, Q: ?Sized, P>
@@ -1393,7 +1384,7 @@ where
     RB: RangeBounds<Q>,
     P: SharedPointerKind,
 {
-    fn new(map: &'a RedBlackTreeMap<K, V, P>, range: RB) -> RangeIterPtr<'_, K, V, RB, Q, P> {
+    fn new(map: &'a RedBlackTreeMap<K, V, P>, range: RB) -> RangeIterPtr<'a, K, V, RB, Q, P> {
         RangeIterPtr { map, stack_forward: None, stack_backward: None, range, _q: PhantomData }
     }
 
