@@ -1,8 +1,3 @@
-/* This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- */
-
 use alloc::borrow::Borrow;
 use alloc::fmt::Display;
 use alloc::vec::Vec;
@@ -345,11 +340,7 @@ where
     pub fn set(&self, index: usize, v: T) -> Option<Vector<T, P>> {
         let mut new_vector = self.clone();
 
-        if new_vector.set_mut(index, v) {
-            Some(new_vector)
-        } else {
-            None
-        }
+        if new_vector.set_mut(index, v) { Some(new_vector) } else { None }
     }
 
     /// Returns `true` if the operation was successful.
@@ -448,11 +439,7 @@ where
     pub fn drop_last(&self) -> Option<Vector<T, P>> {
         let mut new_vector = self.clone();
 
-        if new_vector.drop_last_mut() {
-            Some(new_vector)
-        } else {
-            None
-        }
+        if new_vector.drop_last_mut() { Some(new_vector) } else { None }
     }
 
     pub fn drop_last_mut(&mut self) -> bool {
@@ -802,11 +789,7 @@ where
     }
 
     fn current_forward(&self) -> Option<&'a SharedPointer<T, P>> {
-        if self.non_empty() {
-            IterPtr::current(self.stack_forward.as_ref().unwrap())
-        } else {
-            None
-        }
+        if self.non_empty() { IterPtr::current(self.stack_forward.as_ref().unwrap()) } else { None }
     }
 
     fn advance_backward(&mut self) {
@@ -864,7 +847,7 @@ where
     }
 }
 
-impl<'a, T, P> ExactSizeIterator for IterPtr<'a, T, P> where P: SharedPointerKind {}
+impl<T, P> ExactSizeIterator for IterPtr<'_, T, P> where P: SharedPointerKind {}
 
 #[cfg(feature = "serde")]
 pub mod serde {
